##############################################################################
# ScoDoc
# Copyright (c) 1999 - 2021 Emmanuel Viennet.  All rights reserved.
# See LICENSE
##############################################################################

import numpy as np

"""Quelques classes auxiliaires pour les calculs des notes
"""


class StatsMoyenne:
    """Une moyenne d'un ensemble étudiants sur quelque chose
    (moyenne générale d'un semestre, d'un module, d'un groupe...)
    et les statistiques associées: min, max, moy, effectif
    """

    def __init__(self, vals):
        """Calcul les statistiques.
        Les valeurs NAN ou non numériques sont toujours enlevées.
        """
        self.moy = np.nanmean(vals)
        self.min = np.nanmin(vals)
        self.max = np.nanmax(vals)
        self.size = len(vals)
        self.nb_vals = self.size - np.count_nonzero(np.isnan(vals))

    def to_dict(self):
        "Tous les attributs dans un dict"
        return {
            "min": self.min,
            "max": self.max,
            "moy": self.moy,
            "size": self.size,
            "nb_vals": self.nb_vals,
        }
